"use strict";

var _transform = require("./transform");

var _query = require("./query");

const ordersQuery = `
query {
  orders(first: 100) {
    edges {
      node {
        id
        name
        createdAt
        customer {
          displayName
          email
        }
        fullyPaid
        displayFulfillmentStatus
        totalTaxSet {
          shopMoney {
            amount
          }
        }
        totalShippingPriceSet {
          shopMoney {
            amount
          }
        }
        totalReceivedSet {
          shopMoney {
            amount
          }
        }
        lineItems(first: 50) {
          edges {
            node {
              id
              quantity
              product {
                id
                title
                priceRange {
                  maxVariantPrice {
                    amount
                  }
                }
              }
              variant {
                id
                price
              }
            }
          }
        }
      }
    }
  }
}
`;
const productsQuery = `
query {
  products(first: 100) {
    edges {
      node {
        id
      }
    }
  }
}
`;

exports.sourceNodes = async ({
  actions,
  reporter
}, options) => {
  try {
    const {
      createNode
    } = actions;
    const orders = await (0, _query.createQuery)(ordersQuery, {
      LineItem: 'lineItems'
    }, options, reporter);
    reporter.info(`gatsby-source-shopify-graphql fetched ${orders.length} orders`);
    orders.forEach(order => createNode((0, _transform.transformOrderNode)(order)));
    const products = await (0, _query.createQuery)(productsQuery, {
      Variant: 'variants'
    }, options, reporter);
    reporter.info(`gatsby-source-shopify-graphql fetched ${products.length} products`);
    products.forEach(product => createNode((0, _transform.transformProductNode)(product)));
  } catch (error) {
    reporter.panicOnBuild(error);
  }

  return;
};